@@ -29,9 +29,10 @@ from .exceptions import (
     CLIVersionError,
     CookieError,
 )
+from .models import CookieStatus, CookieStatusEntry, WebAuthnDevice
 from .tokens import TokenResult
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 __all__ = [
     # Main functions
@@ -39,9 +40,14 @@ __all__ = [
     "get_token",
     "device_flow",
     "load_cookies",
+    "list_webauthn_devices",
+    "check_status",
     # Classes
     "CERNSSOClient",
     "TokenResult",
+    "WebAuthnDevice",
+    "CookieStatus",
+    "CookieStatusEntry",
     # Utilities
     "to_requests_jar",
     # Exceptions
@@ -65,6 +71,9 @@ def get_cookies(
     use_webauthn: bool = False,
     webauthn_pin: Optional[str] = None,
     webauthn_device: Optional[str] = None,
+    webauthn_device_index: Optional[int] = None,
+    webauthn_timeout: Optional[int] = None,
+    browser: bool = False,
     keytab: Optional[str] = None,
     use_keytab: bool = False,
     use_password: bool = False,
@@ -90,6 +99,9 @@ def get_cookies(
         use_webauthn: Force WebAuthn method even if OTP is default.
         webauthn_pin: PIN for FIDO2 security key.
         webauthn_device: Path to specific FIDO2 device.
+        webauthn_device_index: Index of FIDO2 device (from list_webauthn_devices).
+        webauthn_timeout: Timeout in seconds for FIDO2 device interaction.
+        browser: Use browser for authentication (supports Touch ID, etc.).
         keytab: Path to Kerberos keytab file.
         use_keytab: Force keytab authentication.
         use_password: Force password authentication.
@@ -122,6 +134,9 @@ def get_cookies(
         use_webauthn=use_webauthn,
         webauthn_pin=webauthn_pin,
         webauthn_device=webauthn_device,
+        webauthn_device_index=webauthn_device_index,
+        webauthn_timeout=webauthn_timeout,
+        browser=browser,
         keytab=keytab,
         use_keytab=use_keytab,
         use_password=use_password,
@@ -145,6 +160,9 @@ def get_token(
     use_webauthn: bool = False,
     webauthn_pin: Optional[str] = None,
     webauthn_device: Optional[str] = None,
+    webauthn_device_index: Optional[int] = None,
+    webauthn_timeout: Optional[int] = None,
+    browser: bool = False,
     keytab: Optional[str] = None,
     use_keytab: bool = False,
     use_password: bool = False,
@@ -170,6 +188,9 @@ def get_token(
         use_webauthn: Force WebAuthn method even if OTP is default.
         webauthn_pin: PIN for FIDO2 security key.
         webauthn_device: Path to specific FIDO2 device.
+        webauthn_device_index: Index of FIDO2 device (from list_webauthn_devices).
+        webauthn_timeout: Timeout in seconds for FIDO2 device interaction.
+        browser: Use browser for authentication (supports Touch ID, etc.).
         keytab: Path to Kerberos keytab file.
         use_keytab: Force keytab authentication.
         use_password: Force password authentication.
@@ -202,6 +223,9 @@ def get_token(
         use_webauthn=use_webauthn,
         webauthn_pin=webauthn_pin,
         webauthn_device=webauthn_device,
+        webauthn_device_index=webauthn_device_index,
+        webauthn_timeout=webauthn_timeout,
+        browser=browser,
         keytab=keytab,
         use_keytab=use_keytab,
         use_password=use_password,
@@ -271,3 +295,67 @@ def device_flow(
         auth_host=auth_host,
         realm=realm,
     )
+
+
+def list_webauthn_devices() -> list[WebAuthnDevice]:
+    """List available FIDO2/WebAuthn devices.
+
+    This is a convenience function that uses the default client.
+    For more control, use CERNSSOClient directly.
+
+    Returns:
+        List of WebAuthnDevice objects representing connected devices.
+
+    Raises:
+        CLINotFoundError: If cern-sso-cli is not installed.
+
+    Example:
+        >>> devices = list_webauthn_devices()
+        >>> for d in devices:
+        ...     print(f"{d.index}: {d.product}")
+        0: YubiKey 5 NFC
+
+    Note:
+        This only lists USB/NFC security keys. macOS Touch ID and
+        iCloud Keychain passkeys are not detected by libfido2.
+    """
+    return _get_default_client().list_webauthn_devices()
+
+
+def check_status(
+    file: Union[str, Path],
+    *,
+    url: Optional[str] = None,
+    insecure: bool = False,
+    auth_host: str = "auth.cern.ch",
+) -> CookieStatus:
+    """Check cookie expiration status.
+
+    This is a convenience function that uses the default client.
+    For more control, use CERNSSOClient directly.
+
+    Args:
+        file: Path to cookie file to check.
+        url: URL to verify cookies against (makes HTTP request).
+        insecure: Skip certificate validation when verifying.
+        auth_host: Authentication hostname for verification.
+
+    Returns:
+        CookieStatus object with cookie validity information.
+
+    Raises:
+        CLINotFoundError: If cern-sso-cli is not installed.
+
+    Example:
+        >>> status = check_status("cookies.txt")
+        >>> print(f"Has valid cookies: {status.has_valid_cookies}")
+
+        >>> status = check_status("cookies.txt", url="https://gitlab.cern.ch")
+        >>> print(f"Verified: {status.verified_valid}")
+    """
+    return _get_default_client().check_status(
+        file,
+        url=url,
+        insecure=insecure,
+        auth_host=auth_host,
+    )
